/*******************************************************************************
 * Copyright (c) 2001 IBM Corporation.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v0.5 
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v05.html
 * 
 * Contributors:
 *     IBM Corporation - example implementation
 ******************************************************************************/

package com.example;

import java.util.ArrayList;
import java.util.Arrays;

import org.eclipse.core.resources.ICommand;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IProjectDescription;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.jdt.core.JavaCore;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;

/**
 * Workbench action deletgate for uninstalling the example builder from all 
 * Java projects currently in the workspace.
 */
public class LibCopyUninstall implements IWorkbenchWindowActionDelegate {
	
	static boolean DEBUG = true;
	
	/**
	 * The parent window of this action delegate.
	 */
	private IWorkbenchWindow fWindow;
	
	/*
	 * @see IActionDelegate#run(IAction)
	 */
	public void run(IAction action) {
		// do something only if a single project is selected
		IProject prj;
		ISelection sel = fWindow.getSelectionService().getSelection();
		if (!(sel instanceof IStructuredSelection)) {
			// not a structured selection
			return;
		} else {
			Object o = ((IStructuredSelection) sel).getFirstElement();
			if (!(o instanceof IProject)) {
				// selection is not a project
				return;
			} else {
				prj = (IProject) o;
			}
		}
		if (DEBUG) {
			System.out.println("Starting to uninstall builder from project " + prj.getName());
		}
		
		try {
			if (prj.hasNature(JavaCore.NATURE_ID)) {
				IProjectDescription pd = prj.getDescription();
				ArrayList cmds = new ArrayList(Arrays.asList(pd.getBuildSpec()));
				boolean changed = false;
				for (int j = cmds.size() - 1; j >= 0; j--) {
					ICommand x = (ICommand) cmds.get(j);
					if (x.getBuilderName().equals(LibCopyBuilder.BUILDER_ID)) {
						cmds.remove(j);
						changed = true;
						if (DEBUG) {
							System.out.println(
								"Uninstalled " + LibCopyBuilder.BUILDER_ID + " from " + prj.getName());
						}
						break;
					}
				}
				if (changed) {
					ICommand[] newCmds = new ICommand[cmds.size()];
					cmds.toArray(newCmds);
					pd.setBuildSpec(newCmds);
					prj.setDescription(pd, null);
				}
			}
		} catch (CoreException e) {
			// huh?
			e.printStackTrace();
		}
	}	
	/*
	 * @see IWorkbenchWindowActionDelegate#init(IWorkbenchWindow)
	 */
	public void init(IWorkbenchWindow window) {
		fWindow= window;
	} 
	
	/*
	 * @see IActionDelegate#selectionChanged(IAction, ISelection)
	 */
	public void selectionChanged(IAction action, ISelection selection) {
	}
	
	/*
	 * @see IWorkbenchWindowActionDelegate#dispose()
	 */
	public void dispose() {
	}
}
 